@@ -20,7 +20,7 @@ class FeatureSelector(TransformerMixin):
         self.selector = BorutaPy(estimator=RandomForestRegressor(max_depth=self.params['max_depth'], n_jobs=-1),
                                  max_iter=200, n_estimators='auto')
 
-        numeric_features = [col for col in X.columns if is_numeric_dtype(X[col])]
+        numeric_features = [col for col in X.columns if is_numeric_dtype(X[col]) or np.all(X[col].str.isnumeric())]
         if numeric_features:
             X_boruta = X[numeric_features]
 
@@ -53,16 +53,16 @@ class Estimator(BaseEstimator):
     def fit(self, X, y=None):
         if type(X) == np.ndarray:
             X = pd.DataFrame(X)
-        if not (isinstance(self.model, CatBoostClassifierScikit) or isinstance(self.model, CatBoostRegressorScikit)):
-            X = pd.get_dummies(data = X, drop_first = True)
-        
+        # if not (isinstance(self.model, CatBoostClassifierScikit) or isinstance(self.model, CatBoostRegressorScikit)):
+        #     X = pd.get_dummies(data = X, drop_first = True)
         return self.model.fit(X, y)
 
     def predict(self, X):
+    
         if type(X) == np.ndarray:
                 X = pd.DataFrame(X)
                 
-        numeric_features = [col for col in X.columns if is_numeric_dtype(X[col])]
+        numeric_features = [col for col in X.columns if is_numeric_dtype(X[col]) or np.all(X[col].str.isnumeric())]
 
         if numeric_features:
             for col in X[numeric_features].columns.copy():
@@ -92,7 +92,7 @@ class CustomImputer:
         if type(X) == np.ndarray:
             X = pd.DataFrame(X)
             X = X.convert_dtypes(convert_integer=True, convert_string = False)
-            numeric_features_index = [X.columns.get_loc(x) for x in X.columns if is_numeric_dtype(X[x])]
+            numeric_features_index = [X.columns.get_loc(col) for col in X.columns if is_numeric_dtype(X[col]) or np.all(X[col].str.isnumeric())]
             if numeric_features_index:
                 for feat in X.columns:
                     if feat in X.columns[numeric_features_index]:
@@ -115,7 +115,7 @@ class CustomImputer:
         if type(X) == np.ndarray:
             X = pd.DataFrame(X)
             X = X.convert_dtypes(convert_integer=True, convert_string = False)
-        numeric_features_index = [X.columns.get_loc(x) for x in X.columns if is_numeric_dtype(X[x])]
+        numeric_features_index = [X.columns.get_loc(x) for x in X.columns if is_numeric_dtype(X[x]) or np.all(X[x].str.isnumeric())]
         if numeric_features_index:
             for feat in X.columns.copy().values:
                 if feat in X.columns[numeric_features_index].copy():
@@ -131,9 +131,21 @@ class CustomImputer:
 
 class GetDummiesTransformer(TransformerMixin):  
     def __init__(self) -> None:
+        self.training_columns = None
         pass
     def fit(self, X, y=None):
         return self
     def transform(self, X, y = None):
-        X = pd.get_dummies(X, drop_first=True)
+       
+        cats = [col for col in X.columns if X[col].dtypes == 'object']
+        X = pd.get_dummies(X, drop_first=True, columns = cats)
+        if not np.any(self.training_columns):
+            self.training_columns = X.columns
+        else:
+            missing_cols = set(self.training_columns) - set(X.columns )
+
+            for col in missing_cols:
+                X[col] = 0
+            X = X[self.training_columns]
+        
         return X
\ No newline at end of file
