@@ -71,8 +71,10 @@ class SearchSpaces(Enum):
                         'cat_smooth': [20, 30]}]
 
     LOGISTIC_REGRESSION = [{'estimator': ['logistic_regressor'],
-                            'solver': ['newton-cg', 'lbfgs', 'liblinear', 'sag', 'saga'],
-                            'C': [1, 0.8, 0.7, 0.5, 0.3]}]
+                            # 'solver': ['lbfgs', 'liblinear', 'saga'],
+                            'C': [1]
+                            # 'C': [1, 0.8, 0.5, 0.3]}
+                            }]
 
 
     DECISION_TREE_REGRESSOR = [{'estimator': ['decision_tree'],
