@@ -1,4 +1,5 @@
 import pandas as pd
+from pandas.api.types import is_numeric_dtype
 import numpy as np
 
 from sklearn.metrics import roc_auc_score
@@ -34,8 +35,9 @@ class OptunaObjectives:
         xgbClassifier = XGBClassifier(**params)
 
         try:
-            numeric_features = [col for col in X.columns if X[col].dtypes == 'int64' or X[col].dtypes == 'float64' 
-                                or X[col].dtypes == 'int' or X[col].dtypes == 'float']
+            # numeric_features = [col for col in X.columns if X[col].dtypes == 'int64' or X[col].dtypes == 'float64' 
+            #                     or X[col].dtypes == 'int' or X[col].dtypes == 'float']
+            numeric_features = [col for col in X.columns if is_numeric_dtype(X[col]) or np.all(X[col].str.isnumeric())]
             if numeric_features:
                 for feat in numeric_features.copy():
                     X.loc[:][feat] = X[feat].astype('float64')
@@ -71,8 +73,8 @@ class OptunaObjectives:
         xgbRegressor = XGBRegressor(**params)
 
         try:
-            numeric_features = [col for col in X.columns if X[col].dtypes == 'int64' or X[col].dtypes == 'float64' 
-                                or X[col].dtypes == 'int' or X[col].dtypes == 'float']
+            numeric_features = [col for col in X.columns if is_numeric_dtype(X[col]) or np.all(X[col].str.isnumeric())]
+                   
             if numeric_features:
                 for feat in numeric_features:
                     X.loc[:][feat] = X[feat].astype('float64')
@@ -103,8 +105,7 @@ class OptunaObjectives:
         catboostClassifier = CatBoostClassifier(**params)
 
         try:
-            numeric_features = [col for col in X.columns if X[col].dtypes == 'int64' or X[col].dtypes == 'float64' 
-                                or X[col].dtypes == 'int' or X[col].dtypes == 'float']
+            numeric_features = [col for col in X.columns if is_numeric_dtype(X[col]) or np.all(X[col].str.isnumeric())]
             if numeric_features:
                 for feat in numeric_features:
                     # X.loc[:,X.columns == feat] =X.loc[:,X.columns == feat].astype('float64')
@@ -146,8 +147,7 @@ class OptunaObjectives:
         
         catboostClassifier = CatBoostClassifier(**params)
         try:
-            numeric_features = [col for col in X.columns if X[col].dtypes == 'int64' or X[col].dtypes == 'float64' 
-                                or X[col].dtypes == 'int' or X[col].dtypes == 'float']
+            numeric_features = [col for col in X.columns if is_numeric_dtype(X[col]) or np.all(X[col].str.isnumeric())]
             if numeric_features:
                 for feat in numeric_features:
                     X.loc[:][feat] = X[feat].astype('float64')
@@ -183,8 +183,7 @@ class OptunaObjectives:
         }
         catboostRegressor = CatBoostRegressor(**params)
         try:
-            numeric_features = [col for col in X.columns if X[col].dtypes == 'int64' or X[col].dtypes == 'float64' 
-                                or X[col].dtypes == 'int' or X[col].dtypes == 'float']
+            numeric_features = [col for col in X.columns if is_numeric_dtype(X[col]) or np.all(X[col].str.isnumeric())]
             if numeric_features:
                 for feat in numeric_features:
                     X.loc[:][feat] = X[feat].astype('float64')
@@ -227,8 +226,7 @@ class OptunaObjectives:
         LGBMClf = LGBMClassifier(**params)
 
         try:
-            numeric_features = [col for col in X.columns if X[col].dtypes == 'int64' or X[col].dtypes == 'float64' 
-                                or X[col].dtypes == 'int' or X[col].dtypes == 'float']
+            numeric_features = [col for col in X.columns if is_numeric_dtype(X[col]) or np.all(X[col].str.isnumeric())]
             if numeric_features:
                 for feat in numeric_features:
                     X.loc[:][feat] = X[feat].astype('float64')
@@ -266,8 +264,7 @@ class OptunaObjectives:
         LGBMClf = LGBMClassifier(**params)
 
         try:
-            numeric_features = [col for col in X.columns if X[col].dtypes == 'int64' or X[col].dtypes == 'float64' 
-                                or X[col].dtypes == 'int' or X[col].dtypes == 'float']
+            numeric_features = [col for col in X.columns if is_numeric_dtype(X[col]) or np.all(X[col].str.isnumeric())]
             if numeric_features:
                 for feat in numeric_features:
                     X.loc[:][feat] = X[feat].astype('float64')
@@ -307,8 +304,7 @@ class OptunaObjectives:
         LGBMRgs = LGBMRegressor(**params)
 
         try:
-            numeric_features = [col for col in X.columns if X[col].dtypes == 'int64' or X[col].dtypes == 'float64' 
-                                or X[col].dtypes == 'int' or X[col].dtypes == 'float']
+            numeric_features = [col for col in X.columns if is_numeric_dtype(X[col]) or np.all(X[col].str.isnumeric())]
             if numeric_features:
                 for feat in numeric_features:
                     X.loc[:][feat] = X[feat].astype('float64')
@@ -329,8 +325,7 @@ class OptunaObjectives:
         DTClassifier = DecisionTreeClassifier(**params)
 
         try:
-            numeric_features = [col for col in X.columns if X[col].dtypes == 'int64' or X[col].dtypes == 'float64' 
-                                or X[col].dtypes == 'int' or X[col].dtypes == 'float']
+            numeric_features = [col for col in X.columns if is_numeric_dtype(X[col]) or np.all(X[col].str.isnumeric())]
             if numeric_features:
                 for feat in numeric_features:
                     X.loc[:][feat] = X[feat].astype('float64')
@@ -360,8 +355,7 @@ class OptunaObjectives:
 
 
         try:
-            numeric_features = [col for col in X.columns if X[col].dtypes == 'int64' or X[col].dtypes == 'float64' 
-                                or X[col].dtypes == 'int' or X[col].dtypes == 'float']
+            numeric_features = [col for col in X.columns if is_numeric_dtype(X[col]) or np.all(X[col].str.isnumeric())]
             if numeric_features:
                 for feat in numeric_features:
                     X.loc[:][feat] = X[feat].astype('float64')
@@ -383,8 +377,7 @@ class OptunaObjectives:
         adaboost_clf = AdaBoostClassifier(**params)
 
         try:
-            numeric_features = [col for col in X.columns if X[col].dtypes == 'int64' or X[col].dtypes == 'float64' 
-                                or X[col].dtypes == 'int' or X[col].dtypes == 'float']
+            numeric_features = [col for col in X.columns if is_numeric_dtype(X[col]) or np.all(X[col].str.isnumeric())]
             if numeric_features:
                 for feat in numeric_features:
                     X.loc[:][feat] = X[feat].astype('float64')
@@ -413,8 +406,7 @@ class OptunaObjectives:
         adaboostRegressor = AdaBoostRegressor(**params)
 
         try:
-            numeric_features = [col for col in X.columns if X[col].dtypes == 'int64' or X[col].dtypes == 'float64' 
-                                or X[col].dtypes == 'int' or X[col].dtypes == 'float']
+            numeric_features = [col for col in X.columns if is_numeric_dtype(X[col]) or np.all(X[col].str.isnumeric())]
             if numeric_features:
                 for feat in numeric_features:
                     X.loc[:][feat] = X[feat].astype('float64')
@@ -433,8 +425,7 @@ class OptunaObjectives:
         logistic = LogisticRegression(**params)
 
         try:
-            numeric_features = [col for col in X.columns if X[col].dtypes == 'int64' or X[col].dtypes == 'float64' 
-                                or X[col].dtypes == 'int' or X[col].dtypes == 'float']
+            numeric_features = [col for col in X.columns if is_numeric_dtype(X[col]) or np.all(X[col].str.isnumeric())]
             if numeric_features:
                 for feat in numeric_features:
                     X.loc[:][feat] = X[:][feat].astype('float64')
@@ -464,8 +455,7 @@ class OptunaObjectives:
         svr = SVR(**params)
 
         try:
-            numeric_features = [col for col in X.columns if X[col].dtypes == 'int64' or X[col].dtypes == 'float64' 
-                                or X[col].dtypes == 'int' or X[col].dtypes == 'float']
+            numeric_features = [col for col in X.columns if is_numeric_dtype(X[col]) or np.all(X[col].str.isnumeric())]
             if numeric_features:
                 for feat in numeric_features:
                     X.loc[:][feat] = X[feat].copy().astype('float64')
