@@ -3,7 +3,7 @@ from pandas.api.types import is_numeric_dtype
 import pandas as pd
 import numpy as np
 
-class CatBoostClassifierScikit:
+class CatBoostClassifierScikit(CatBoostClassifier):
     def __init__(self, params={}) -> None:
         self.classifier = CatBoostClassifier(**params)
 
@@ -53,7 +53,7 @@ class CatBoostClassifierScikit:
     def set_params(self, **params):
         self.classifier.set_params(**params)
 
-
+    
        
 class CatBoostRegressorScikit:
     def __init__(self, params={}):
